@@ -225,7 +225,9 @@ def generate_loader_by_foreign_key(fk: ForeignKey, reverse=False):
             results_by_ids = defaultdict(list)
 
             conversion_type = object_type or table_to_class(target)
-            for result in map(dict, await self.session.execute(q.distinct())):
+            results = map(dict, await self.session.execute(q))
+
+            for result in results:
                 _batch_key = result.pop("_batch_key")
                 _data = filter_requested_fields_for_object(result, conversion_type)
                 results_by_ids[_batch_key].append(conversion_type(**_data))
